@@ -7,8 +7,9 @@ from visualgc_remote_control.enterprise import RemoteControlException
 from visualgc_remote_control.remote_control_app import RemoteControlApp
 from visualgc_remote_control.remote_commands import RemoteCommand
 
-# VERSION = '0.0.1'  # Initial version
-VERSION = '0.0.2'  # Redo imports
+# VERSION = '0.0.4'  # Redo imports
+# VERSION = '0.0.5'  # Use absolute path
+VERSION = '0.0.6'  # Add test folder command line
 
 
 class VisualgcRemoteControl:
@@ -16,6 +17,7 @@ class VisualgcRemoteControl:
     def __init__(self):
         self.current_dir = os.path.dirname(os.path.abspath(__file__))
         self.work_dir = os.path.join(self.current_dir, 'tmp')
+        self.commands = RemoteCommand()
         msg = f'running on Python {sys.version_info.major}.{sys.version_info.minor}.{sys.version_info.micro}-{sys.version_info.releaselevel}'
         logging.debug(msg)
 
@@ -52,6 +54,7 @@ class VisualgcRemoteControl:
         subparsers.dest = 'command'
         subparser = subparsers.add_parser("START_SERVER", help="Accept certificate from the controller")
         subparser = subparsers.add_parser("ACCEPT_CERTIFICATE", help="Accept certificate from the controller")
+        subparser = subparsers.add_parser("TEST_FOLDER", help="Test Folder")
         subparsers.add_parser("VERSION", help="Print version")
         ret = 0
 
@@ -73,7 +76,10 @@ class VisualgcRemoteControl:
 
     def accept_certificate(self):
         # run autoit executable
-        RemoteCommand.accept_certificate()
+        self.commands.accept_certificate()
+
+    def test_folder(self):
+        self.commands.test_script_folder()
 
     def start_server(self):
         my_server = RemoteControlApp.run()
